@@ -11,6 +11,7 @@ while [[ "$#" -gt 0 ]]; do
     '-f'|'--force-build') forceBuild=1; shift 0;;
     '-p'|'--force-pull') forcePull=1; shift 0;;
     '-s'|'--scratch') scratchFlag="--scratch"; shift 0;;
+    *) JOB_BRANCH="$1"; shift 0;;
   esac
   shift 1
 done
@@ -22,12 +23,10 @@ function log()
   fi
 }
 
-KUBECTL_VERSION="v1.18.3" # see https://github.com/kubernetes/kubernetes/releases/ or $(curl -s https://storage.googleapis.googleapis.com/kubernetes-release/release/stable.txt)
-KAMEL_VERSION="1.0.1" # see https://github.com/redhat-developer/codeready-workspaces-deprecated/blob/master/kamel/build.sh#L16 or https://github.com/apache/camel-k/releases
+KUBECTL_VERSION="v1.18.10" # see https://github.com/kubernetes/kubernetes/releases/ or $(curl -s https://storage.googleapis.googleapis.com/kubernetes-release/release/stable.txt)
+KAMEL_VERSION="1.2.0" # see https://github.com/redhat-developer/codeready-workspaces-deprecated/blob/master/kamel/build.sh#L16 or https://github.com/apache/camel-k/releases
 
-JOB_BRANCH="master"
-UPSTREAM_JOB_NAME="crw-deprecated_${JOB_BRANCH}"
-jenkinsURL="https://codeready-workspaces-jenkins.rhev-ci-vms.eng.rdu2.redhat.com/job/${UPSTREAM_JOB_NAME}/lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/kamel/target"
+jenkinsURL="https://codeready-workspaces-jenkins.rhev-ci-vms.eng.rdu2.redhat.com/job/crw-deprecated_${JOB_BRANCH}/lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/kamel/target"
 
 # patch Dockerfile to record versions we expect
 sed Dockerfile \
@@ -56,7 +55,7 @@ if [[ $(diff -U 0 --suppress-common-lines -b Dockerfile Dockerfile.2) ]] || [[ $
   rhpkg new-sources asset-*.tar.gz
   log "[INFO] Commit new sources"
   COMMIT_MSG="kubectl ${KUBECTL_VERSION}, kamel ${KAMEL_VERSION}"
-  if [[ $(git commit -s -m "[get sources] ${COMMIT_MSG}" sources Dockerfile) == *"nothing to commit, working tree clean"* ]]; then 
+  if [[ $(git commit -s -m "[get sources] ${COMMIT_MSG}" sources Dockerfile .gitignore) == *"nothing to commit, working tree clean"* ]]; then 
     log "[INFO] No new sources, so nothing to build."
   elif [[ ${doRhpkgContainerBuild} -eq 1 ]]; then
     log "[INFO] Push change:"
@@ -64,9 +63,9 @@ if [[ $(diff -U 0 --suppress-common-lines -b Dockerfile Dockerfile.2) ]] || [[ $
   fi
   if [[ ${doRhpkgContainerBuild} -eq 1 ]]; then
     echo "[INFO] Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
-    tmpfile=`mktemp` && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
+    tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
     taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
-    ERRORS="$(egrep "image build failed" $tmpfile)" && rm -f $tmpfile
+    ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
     if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
 
 $ERRORS
@@ -76,9 +75,9 @@ $ERRORS
 else
 	if [[ ${forceBuild} -eq 1 ]]; then
     echo "[INFO] Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
-    tmpfile=`mktemp` && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
+    tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
     taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
-    ERRORS="$(egrep "image build failed" $tmpfile)" && rm -f $tmpfile
+    ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
     if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
 
 $ERRORS
